==> rlclientbdr-1.1-py3-none-any.whl: rlclient/client.py <==
import requests


class RLClient:
    def __init__(self, name, password, hostname="10.216.3.238"):
        self.TEAM_NAME = name
        self.TEAM_PASSWORD = password
        self.SERVER = "http://" + hostname + ":" + PORT + '/rl'

    @staticmethod
    def validate_ids(run_id, request_number):
        if run_id < 0:
            raise ValueError("run_id has an invalid value of {}".format(run_id))

        if request_number < 0 or request_number > 9999:
            raise ValueError("request_number has an invalid value of {}".format(request_number))

    def get_context(self, run_id, request_number):
        self.validate_ids(run_id, request_number)

        params = {
            "team_id": self.TEAM_NAME,
            "team_password": self.TEAM_PASSWORD,
            "run_id": run_id,
            "request_number": request_number
        }

        r = requests.get(self.SERVER + "/get_context", params=params)
        if not r.status_code == 200:
            print(r.text)
            raise Exception("Something went wrong, see message above.")
        else:
            return r.json()

    def serve_page(self, run_id, request_number, header, language, adtype, color, price):
        self.validate_ids(run_id, request_number)

        data = {
            "team_id": self.TEAM_NAME,
            "team_password": self.TEAM_PASSWORD,
            "run_id": run_id,
            "request_number": request_number,
            "header": header,
            "language": language,
            "adtype": adtype,
            "color": color,
            "price": price
        }

        r = requests.post(self.SERVER + "/serve_page", data=data)
        if not r.status_code == 200:
            print(r.text)
            raise Exception("Something went wrong, see message above.")
        else:
            return r.json()

    def reset_leaderboard(self):
        data = {
            "team_id": self.TEAM_NAME,
            "team_password": self.TEAM_PASSWORD
        }
        r = requests.post(self.SERVER + "/reset_leaderboard", data=data)
        if not r.status_code == 200:
            print(r.text)
            raise Exception("Something went wrong, see message above.")
        else:
            return r.json()

==> rlclientbdr-1.11-py3-none-any.whl: rlclient/client.py <==
import requests


class RLClient:
    def __init__(self, name, password, hostname="10.216.3.238"):
        self.TEAM_NAME = name
        self.TEAM_PASSWORD = password
        self.SERVER = "http://" + hostname + ":80/rl"

    @staticmethod
    def validate_ids(run_id, request_number):
        if run_id < 0:
            raise ValueError("run_id has an invalid value of {}".format(run_id))

        if request_number < 0 or request_number > 9999:
            raise ValueError("request_number has an invalid value of {}".format(request_number))

    def get_context(self, run_id, request_number):
        self.validate_ids(run_id, request_number)

        params = {
            "team_id": self.TEAM_NAME,
            "team_password": self.TEAM_PASSWORD,
            "run_id": run_id,
            "request_number": request_number
        }

        r = requests.get(self.SERVER + "/get_context", params=params)
        if not r.status_code == 200:
            print(r.text)
            raise Exception("Something went wrong, see message above.")
        else:
            return r.json()

    def serve_page(self, run_id, request_number, header, language, adtype, color, price):
        self.validate_ids(run_id, request_number)

        data = {
            "team_id": self.TEAM_NAME,
            "team_password": self.TEAM_PASSWORD,
            "run_id": run_id,
            "request_number": request_number,
            "header": header,
            "language": language,
            "adtype": adtype,
            "color": color,
            "price": price
        }

        r = requests.post(self.SERVER + "/serve_page", data=data)
        if not r.status_code == 200:
            print(r.text)
            raise Exception("Something went wrong, see message above.")
        else:
            return r.json()

    def reset_leaderboard(self):
        data = {
            "team_id": self.TEAM_NAME,
            "team_password": self.TEAM_PASSWORD
        }
        r = requests.post(self.SERVER + "/reset_leaderboard", data=data)
        if not r.status_code == 200:
            print(r.text)
            raise Exception("Something went wrong, see message above.")
        else:
            return r.json()
